@@ -1,3 +1,3 @@
 from common.logging_config import get_my_logger, DOCUMENTPATH
 
-logger = get_my_logger(DOCUMENTPATH, "django")
+logger = get_my_logger("django")
