@@ -218,7 +218,7 @@ class BaseView(APIView, Select):
         :param keys:
         :return:
         """
-        results, queryset, current_page_queryset = self.find(obj, request.GET, obj_serializer)
+        results, queryset, current_page_queryset = self.find(obj, request.GET.dict(), obj_serializer)
         if need_results:
             return results
         if need_queryset:
@@ -382,7 +382,7 @@ class BaseJoinView(APIView, Select):
         :param mapping: 需要扩展字段对应的映射
         :return:
         """
-        results, queryset, current_page_queryset = self.find(obj, request.GET, obj_serializer)
+        results, queryset, current_page_queryset = self.find(obj, request.GET.dict(), obj_serializer)
         if results.data and results.data.result and mapping and obj_relevance:
             result = self.extend_result_field(obj_serializer, obj_relevance, m_to_m_obj, mapping, m_to_m_mapping,
                                               current_page_queryset)
